@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Apply arpeggiation patterns to groups of notes
 
-our $VERSION = '0.0202';
+our $VERSION = '0.0203';
 
 use Moo;
 use strictures 2;
@@ -57,7 +57,7 @@ sub arp {
     $type     ||= $self->type;
     $repeats  ||= $self->repeats;
 
-    my $pattern = ref $type eq 'ARRAY' ? $type : $self->build_pattern($type, $notes);
+    my $pattern = ref $type eq 'ARRAY' ? $type : $self->_build_pattern($type, $notes);
 
     my $pat = Array::Circular->new(@$pattern);
 
@@ -79,8 +79,7 @@ sub arp {
     return \@arp;
 }
 
-
-sub build_pattern {
+sub _build_pattern {
     my ($self, $type, $notes) = @_;
     return $self->arp_type($type)->($notes);
 }
@@ -113,7 +112,7 @@ Music::MelodicDevice::Arpeggiation - Apply arpeggiation patterns to groups of no
 
 =head1 VERSION
 
-version 0.0202
+version 0.0203
 
 =head1 SYNOPSIS
 
@@ -201,12 +200,6 @@ Create a new C<Music::MelodicDevice::Arpeggiation> object.
 
 Return a list of lists of C<d#> MIDI-Perl strings with the pitches indexed by the arpeggiated pattern built from the given C<type>. These MIDI-Perl duration strings are distributed evenly across the given C<duration>.
 
-=head2 build_pattern
-
-  my $pattern = $self->build_pattern($type, $notes);
-
-Return an array reference of C<notes> indexes, based on the C<type>, if known.
-
 =head2 arp_type
 
   $all_types = $self->arp_type # get everything
